@@ -6,6 +6,7 @@ import requests
 import sys
 import traceback
 import re
+import types
 
 from abc import abstractmethod
 from bottle import request, response
@@ -193,12 +194,13 @@ class SmStartRequest(SmRequest):
             run_from = orchestration_services[service_name]["runFrom"]
             classifier = orchestration_services[service_name]["classifier"]
             version = orchestration_services[service_name]["version"]
+            append_args = orchestration_services[service_name]["appendArgs"] # Allows for dynamic config overriding
 
             # Allow for deprecated run_from values
             if run_from in deprecated_release_params:
                 run_from = deprecated_release_params[run_from]
 
-            self.context.start_service(service_name, run_from, proxy, classifier, service_mapping_ports, port, admin_port, version)
+            self.context.start_service(service_name, run_from, proxy, classifier, service_mapping_ports, port, admin_port, version, append_args)
 
     def _await_service_startup(self, service_name, port, admin_port):
         seconds_remaining = SERVICE_START_TIMEOUT_SECONDS
@@ -268,6 +270,8 @@ class SmStartRequest(SmRequest):
         if "version" in service_start_request and service_start_request["version"]:
             version = service_start_request["version"]
 
+        append_args = service_start_request.get("appendArgs", [])
+
         if need_classifier:
 
             valid_classifiers = "[" + (",".join(str(x) for x in mapping.keys())) + "]"
@@ -290,7 +294,7 @@ class SmStartRequest(SmRequest):
             service_name = mapping
             classifier = None
 
-        return service_mapping_name, service_name, classifier, version
+        return service_mapping_name, service_name, classifier, version, append_args
 
     def _validate_start_request_and_assign_ports(self, services_to_start, dontrunfromsource):
 
@@ -299,7 +303,10 @@ class SmStartRequest(SmRequest):
 
         for service_start_request in services_to_start:
 
-            service_mapping_name, service_name, classifier, version = self._service_mapping_for(service_start_request)
+            service_mapping_name, service_name, classifier, version, append_args = self._service_mapping_for(service_start_request)
+
+            if append_args and not isinstance(append_args, types.ListType):
+                raise self._bad_request_exception("ERROR: I was passed a non list for append args of '" + str(append_args) + "' I dont know what to do with this")
 
             if service_mapping_name in service_mapping_ports:
                 raise self._bad_request_exception("Duplicate entry for service '%s' in start request" % service_mapping_name)
@@ -313,6 +320,9 @@ class SmStartRequest(SmRequest):
                 if run_from == "SOURCE":
                     raise self._bad_request_exception("runFrom parameter has value '%s', however --nosource was specified when smserver started" % run_from)
 
+            if append_args and not self.context.get_service_starter(service_name, run_from, None).supports_append_args():
+                raise BadRequestException("The service type for '" + service_name + "' does not support append args")
+
             if service_name in orchestration_services:
                 existing_entry = orchestration_services[service_name]
                 service_mapping_ports[service_mapping_name] = existing_entry["port"]
@@ -334,7 +344,8 @@ class SmStartRequest(SmRequest):
                     "adminPort": admin_port,
                     "runFrom": run_from,
                     "classifier": classifier,
-                    "version": version
+                    "version": version,
+                    "appendArgs": append_args
                 }
 
         return orchestration_services, service_mapping_ports
